# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.1.0](https://github.com/conda/rattler/compare/simple_spawn_blocking-v1.0.0...simple_spawn_blocking-v1.1.0) - 2025-02-25

### Added

- add run_exports cache (#1060)
